pub struct CodeParameterEcho {
pub format: Option<String>,
pub lang: Option<String>,
pub db: Option<String>,
pub start_date: Option<String>,
pub end_date: Option<String>,
pub start_position: Option<u32>,
pub extras: BTreeMap<String, String>,
}Expand description
Echoed request parameters for getDataCode.
Fields
format: Option<String>Echoed format parameter, if present in the response payload.
lang: Option<String>Echoed lang parameter, if present in the response payload.
db: Option<String>Echoed db parameter, if present in the response payload.
start_date: Option<String>Echoed startDate parameter, if present in the response payload.
end_date: Option<String>Echoed endDate parameter, if present in the response payload.
start_position: Option<u32>Echoed startPosition parameter, if present in the response payload.
extras: BTreeMap<String, String>Additional parameter echoes not normalized into dedicated fields.